aboutsummaryrefslogtreecommitdiffstats
path: root/scripts
diff options
context:
space:
mode:
authorAlex <git@ajschof.me>2024-09-03 16:07:37 +0100
committerGitHub <noreply@github.com>2024-09-03 16:07:37 +0100
commitce30178558cc8222e9975273eb5d08a93ae92fcc (patch)
tree4152f9efe54364a5d6a6cc969befb6cea9015a5b /scripts
parente4e360630c90d7e801d99097b3e46e8299ab901d (diff)
parent3b8e89968e3d3d3527ea76b4517b0d7278512530 (diff)
downloadde-project-bentley-ce30178558cc8222e9975273eb5d08a93ae92fcc.tar.gz
de-project-bentley-ce30178558cc8222e9975273eb5d08a93ae92fcc.zip
Merge branch 'development' into test/tests_transform_lambda
Diffstat (limited to 'scripts')
-rwxr-xr-xscripts/make_layer_zip.sh17
1 files changed, 13 insertions, 4 deletions
diff --git a/scripts/make_layer_zip.sh b/scripts/make_layer_zip.sh
index eabe301..7f64873 100755
--- a/scripts/make_layer_zip.sh
+++ b/scripts/make_layer_zip.sh
@@ -1,8 +1,17 @@
# Description: Make the zip file for the layer
cd "$(dirname "$0")/.."
+
+# Layer 01
+mkdir -p python/lib/python3.11/site-packages
+pip3 install --upgrade -r requirements_lambda_01.txt -t python/lib/python3.11/site-packages
+rm layer_01.zip
+zip -r layer_01.zip python
+rm -r python/
+
+# Layer 02
mkdir -p python/lib/python3.11/site-packages
-pip3 install --upgrade -r requirements.txt -t python/lib/python3.11/site-packages
-rm layer.zip
-zip -r layer.zip python
+pip3 install --upgrade -r requirements_lambda_02.txt -t python/lib/python3.11/site-packages
+rm layer_02.zip
+zip -r layer_02.zip python
rm -r python/
git.ajschof.me — hosted by ajschofield — powered by cgit
@@ -1,8 +1,17 @@
-# Description: Make the zip file for the layer
+# Description: Make the zip file for the layer for the extract lambda function
cd "$(dirname "$0")/.."